@@ -683,7 +683,7 @@ nco_yyerror /* [fnc] Print error/warning/info messages generated by parser */
     if(nco_dbg_lvl_get() >= nco_dbg_fl) (void)fprintf(stderr," %s",err_sng_lcl);
     (void)fprintf(stderr,"\n");
     (void)fflush(stderr);
-  } /* endif dbg */
+  } /* !dbg */
   
   if(err_sng_lcl[0] == '#') eprovoke_skip=True;
   eprovoke_skip=eprovoke_skip+0; /* CEWI Do nothing except avoid compiler warnings */
