@@ -70,6 +70,7 @@
 
 /* Standard C headers */
 #include <assert.h> /* assert() */
+#include <fenv.h> /* fesetexceptflag() */
 #include <stdio.h> /* stderr, FILE, NULL, etc. */
 #include <stdlib.h> /* abs, getopt, malloc, strtol */
 #include <string.h> /* strcmp() */
@@ -271,6 +272,7 @@ main(int argc,char **argv)
   nco_bool HAVE_LIMITS=False; /* [flg] Are there user limits? (-d) */
   nco_bool HISTORY_APPEND=True; /* Option h */
   nco_bool HPSS_TRY=False; /* [flg] Search HPSS for unfound files */
+  nco_bool LST_HRZ=False; /* [flg] Print extraction list of horizontal (lat,lon,ncol,time) variables */
   nco_bool LST_RNK_GE2=False; /* [flg] Print extraction list of rank >= 2 variables */
   nco_bool LST_XTR=False; /* [flg] Print extraction list */
   nco_bool MSA_USR_RDR=False; /* [flg] Multi-Slab Algorithm returns hyperslabs in user-specified order */
@@ -305,6 +307,7 @@ main(int argc,char **argv)
   nco_bool WRT_TMP_FL=True; /* [flg] Write output to temporary file */
   nco_bool flg_area_wgt=False; /* [flg] Area-weight map-file statistics */
   nco_bool flg_dmm_in=False; /* [flg] Make dummy input file */
+  nco_bool flg_fpe=False; /* [flg] Activate/report floating-point-exceptions */
   nco_bool flg_frac_b_nrm=False; /* [flg] Normalize map-file weights when frac_b >> 1 */
   nco_bool flg_mmr_cln=True; /* [flg] Clean memory prior to exit */
   nco_bool flg_rgr=False; /* [flg] Regrid */
@@ -375,6 +378,8 @@ main(int argc,char **argv)
     {"cpy",no_argument,0,0},
     {"dmm_in_mk",no_argument,0,0}, /* [flg] Make dummy input file */
     {"fl_dmm",no_argument,0,0}, /* [flg] Make dummy input file */
+    {"fpe",no_argument,0,0}, /* [flg] Activate floating-point-exceptions */
+    {"floating_point_exceptions",no_argument,0,0}, /* [flg] Activate floating-point-exceptions */
     {"license",no_argument,0,0},
     {"hdf4",no_argument,0,0}, /* [flg] Treat file as HDF4 */
     {"hdn",no_argument,0,0}, /* [flg] Print hidden attributes */
@@ -385,6 +390,7 @@ main(int argc,char **argv)
     {"id",no_argument,0,0}, /* [flg] Print normally hidden information, like file, group, and variable IDs */
     {"lbr",no_argument,0,0},
     {"library",no_argument,0,0},
+    {"lst_hrz",no_argument,0,0}, /* [flg] Print extraction list of horizontal (lat,lon,ncol,time) variables */
     {"lst_rnk_ge2",no_argument,0,0}, /* [flg] Print extraction list of rank >= 2 variables */
     {"lst_xtr",no_argument,0,0}, /* [flg] Print extraction list */
     {"frac_b_nrm",no_argument,0,0}, /* [flg] Normalize map-file weights when frac_b >> 1 */
@@ -758,6 +764,18 @@ main(int argc,char **argv)
         rec_dmn_nm=strcat(rec_dmn_nm,optarg);
         rec_dmn_nm_fix=strdup(optarg);
       } /* !fix_rec_dmn */
+      if(!strcmp(opt_crr,"fpe") || !strcmp(opt_crr,"floating_point_exceptions")){
+	flg_fpe=True;
+	/* https://www.tutorialspoint.com/c_standard_library/c_function_fesetexceptflag.htm */
+	fexcept_t flg_xcp;
+	// Clear all exceptions
+	feclearexcept(FE_ALL_EXCEPT);
+	if(fesetexceptflag(&flg_xcp,FE_INVALID|FE_DIVBYZERO|FE_OVERFLOW) != 0){
+	  (void)fprintf(stdout,"%s: Failed to set FE_INVALID|FE_DIVBYZERO|FE_OVERFLOW exception flags\n",nco_prg_nm_get());
+	}else{
+	  (void)fprintf(stdout,"%s: Successfully set FE_INVALID|FE_DIVBYZERO|FE_OVERFLOW exception flags\n",nco_prg_nm_get());
+	} /* !fesetexceptflag() */
+      } /* !fpe */
       if(!strcmp(opt_crr,"cmp") || !strcmp(opt_crr,"cmp_sng") || !strcmp(opt_crr,"ccr") || !strcmp(opt_crr,"cdc") || !strcmp(opt_crr,"codec") || !strcmp(opt_crr,"compress")) cmp_sng=(char *)strdup(optarg);
       if(!strcmp(opt_crr,"fl_fmt") || !strcmp(opt_crr,"file_format")) rcd=nco_create_mode_prs(optarg,&fl_out_fmt);
       if(!strcmp(opt_crr,"fl_prn") || !strcmp(opt_crr,"file_print") || !strcmp(opt_crr,"prn_fl") || !strcmp(opt_crr,"print_file")) fl_prn=(char *)strdup(optarg);
@@ -792,7 +810,8 @@ main(int argc,char **argv)
 	if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtol",sng_cnv_rcd);
 	nc_set_log_level(log_lvl);
       } /* !log_lvl */
-      if(!strcmp(opt_crr,"lst_rnk_ge2") || !strcmp(opt_crr,"rank_ge2"))	LST_RNK_GE2=True; /* [flg] Print extraction list of rank >= 2 variables */
+      if(!strcmp(opt_crr,"lst_hrz")) LST_HRZ=True; /* [flg] Print extraction list of horizontal (lat,lon,ncol,time) */
+      if(!strcmp(opt_crr,"lst_rnk_ge2")) LST_RNK_GE2=True; /* [flg] Print extraction list of rank >= 2 variables */
       if(!strcmp(opt_crr,"lst_xtr") || !strcmp(opt_crr,"xtr_lst")) LST_XTR=True; /* [flg] Print extraction list */
       if(!strcmp(opt_crr,"mk_rec_dmn") || !strcmp(opt_crr,"mk_rec_dim")){
 	if(strchr(optarg,',')){
@@ -874,7 +893,7 @@ main(int argc,char **argv)
 	rgr_var=(char *)strdup(optarg);
       } /* !rgr_var */
       if(!strcmp(opt_crr,"secret") || !strcmp(opt_crr,"scr") || !strcmp(opt_crr,"shh")){
-        (void)fprintf(stdout,"Hidden/unsupported NCO options:\nBit-Adjustment Alg.\t--baa, --bit_alg\nBuild-engine\t\t--bld, --build_engine\nByte-swap algorithm\t--bsa, --byte_swap\nCompiler used\t\t--cpl, --compiler\nCopyright\t\t--cpy, --copyright, --license\nHidden functions\t--scr, --shh, --secret\nLibrary used\t\t--lbr, --library\nLog level\t\t--log_lvl, --log_level\nList rank >= 2 vars\t--lst_rnk_ge2\nList extracted vars\t--lst_xtr\nMemory clean\t\t--mmr_cln, --cln, --clean\nMemory dirty\t\t--mmr_drt, --drt, --dirty\nMPI implementation\t--mpi_implementation\nNo-clobber files\t--no_clb, --no-clobber\nPseudonym\t\t--pseudonym, -Y (ncra only)\nSpinlock\t\t--spinlock\nStreams\t\t\t--srm\nSysconf\t\t\t--sysconf\nTest UDUnits\t\t--tst_udunits,'units_in','units_out','cln_sng'? \nVersion\t\t\t--vrs, --version\n\n");
+        (void)fprintf(stdout,"Hidden/unsupported NCO options:\nBit-Adjustment Alg.\t--baa, --bit_alg\nBuild-engine\t\t--bld, --build_engine\nByte-swap algorithm\t--bsa, --byte_swap\nCompiler used\t\t--cpl, --compiler\nCopyright\t\t--cpy, --copyright, --license\nHidden functions\t--scr, --shh, --secret\nLibrary used\t\t--lbr, --library\nLog level\t\t--log_lvl, --log_level\nList horizontal vars\t--lst_hrz\nList rank >= 2 vars\t--lst_rnk_ge2\nList extracted vars\t--lst_xtr\nMemory clean\t\t--mmr_cln, --cln, --clean\nMemory dirty\t\t--mmr_drt, --drt, --dirty\nMPI implementation\t--mpi_implementation\nNo-clobber files\t--no_clb, --no-clobber\nPseudonym\t\t--pseudonym, -Y (ncra only)\nSpinlock\t\t--spinlock\nStreams\t\t\t--srm\nSysconf\t\t\t--sysconf\nTest UDUnits\t\t--tst_udunits,'units_in','units_out','cln_sng'? \nVersion\t\t\t--vrs, --version\n\n");
         nco_exit(EXIT_SUCCESS);
       } /* endif "shh" */
       if(!strcmp(opt_crr,"srm")) PRN_SRM=True; /* [flg] Print ncStream */
@@ -1193,6 +1212,9 @@ main(int argc,char **argv)
   /* [fnc] Print extraction list of N>=D variables and exit */
   if(LST_RNK_GE2) nco_xtr_ND_lst(trv_tbl);
 
+  /* [fnc] Print extraction list of horizontal (lat,lon,ncol,time) variables and exit */
+  if(LST_HRZ) nco_xtr_hrz_lst(trv_tbl);
+
   /* Were all user-specified dimensions found? */ 
   (void)nco_chk_dmn(lmt_nbr,flg_dne);    
 
@@ -1664,6 +1686,16 @@ close_and_free:
   MPI_Finalize();
 #endif /* !ENABLE_MPI */
   
+  if(flg_fpe){
+    int exceptions;
+    exceptions=fetestexcept(FE_ALL_EXCEPT);
+    (void)fprintf(stdout,"%s: FE_DIVBYZERO %s raised\n",nco_prg_nm_get(),(exceptions & FE_DIVBYZERO) ? "is" : "is not");
+    (void)fprintf(stdout,"%s: FE_INEXACT %s raised\n",nco_prg_nm_get(),(exceptions & FE_INEXACT) ? "is" : "is not");
+    (void)fprintf(stdout,"%s: FE_INVALID %s raised\n",nco_prg_nm_get(),(exceptions & FE_INVALID) ? "is" : "is not");
+    (void)fprintf(stdout,"%s: FE_OVERFLOW %s raised\n",nco_prg_nm_get(),(exceptions & FE_OVERFLOW) ? "is" : "is not");
+    (void)fprintf(stdout,"%s: FE_UNDERFLOW %s raised\n",nco_prg_nm_get(),(exceptions & FE_UNDERFLOW) ? "is" : "is not");
+  } /* !flg_fpe */
+
   /* End timer */ 
   ddra_info.tmr_flg=nco_tmr_end; /* [enm] Timer flag */
   rcd+=nco_ddra((char *)NULL,(char *)NULL,&ddra_info);
