@@ -29,7 +29,7 @@
 #include "nco_cnf_typ.h" /* Conform variable types nco_typ_ntg() */
 #include "nco_ctl.h" /* Program flow control functions */
 #include "nco_fl_utl.h" /* File manipulation */
-#include "nco_flt.h" /* Compression filters */
+#include "nco_flt.h" /* Compression filters, nco_qnt_mtd() */
 #include "nco_mmr.h" /* Memory management */
 #include "nco_mss_val.h" /* Missing value utilities */
 #include "nco_omp.h" /* OpenMP utilities */
@@ -198,6 +198,7 @@ extern "C" {
    char * const rgr_grd_dst, /* I [sng] File containing destination grid */
    char * const rgr_hrz, /* I [sng] File containing horizontal coordinate grid */
    char * const rgr_map, /* I [sng] File containing mapping weights from source to destination grid */
+   char * const rgr_nlm, /* I [sng] File containing nonlinear mapping weights from source to destination grid */
    char * const rgr_var, /* I [sng] Variable for special regridding treatment */
    char * const rgr_vrt_in, /* I [sng] File containing input vertical coordinate grid */
    char * const rgr_vrt_out, /* I [sng] File containing output vertical coordinate grid */
